@@ -19,22 +19,23 @@
 */
 
 #include "pixmapsprite.h"
+#include "lskat_debug.h"
 
 // General includes
 #include <math.h>
 
 // Qt includes
-#include <QSizeF>
+#include <QGraphicsScene>
 
 // KDE includes
-#include <kdebug.h>
-#include <kconfig.h>
-#include <kconfiggroup.h>
+#include <KConfig>
+#include <KConfigGroup>
 
 // Constructor for the sprite
 PixmapSprite::PixmapSprite(const QString &id, ThemeManager *theme, int advancePeriod, int no, QGraphicsScene *canvas)
-    : Themable(id, theme), QGraphicsPixmapItem(0, canvas)
+    : Themable(id, theme), QGraphicsPixmapItem(0)
 {
+    canvas->addItem(this);
     hide();
 
     mAnimationState = Idle;
@@ -48,8 +49,9 @@ PixmapSprite::PixmapSprite(const QString &id, ThemeManager *theme, int advancePe
 
 // Constructor for the sprite
 PixmapSprite::PixmapSprite(int advancePeriod, int no, QGraphicsScene *canvas)
-    :  Themable(), QGraphicsPixmapItem(0, canvas)
+    :  Themable(), QGraphicsPixmapItem(0)
 {
+    canvas->addItem(this);
     hide();
 
     mAnimationState = Idle;
@@ -205,11 +207,11 @@ void PixmapSprite::setFrame(int no, bool force)
     resetTransform();
     if (mOffsetStatus)
     {
-        translate(-mHotspots.at(no).x() + offset.x(), -mHotspots.at(no).y() + offset.y());
+        setTransform(QTransform::fromTranslate(-mHotspots.at(no).x() + offset.x(), -mHotspots.at(no).y() + offset.y()), true);
     }
     else
     {
-        translate(-mHotspots.at(no).x(), -mHotspots.at(no).y());
+        setTransform(QTransform::fromTranslate(-mHotspots.at(no).x(), -mHotspots.at(no).y()), true);
     }
     mCurrentFrame = no;
     update();
